@@ -53,6 +53,7 @@ class DynamicFormsSerializer(RenderMixin, ActionMixin):
                 field.read_only = False
                 field.display_form = field.display_table  # filter's form is same as non-filter's table
                 field.allow_tags = False
+                field.password_field = False
 
     @property
     def has_non_field_errors(self):
@@ -166,7 +167,7 @@ class DynamicFormsSerializer(RenderMixin, ActionMixin):
         for field in self._readable_fields:
             try:
                 attribute = field.get_attribute(instance)
-                if isinstance(field, serializers.ListSerializer):
+                if not isinstance(field, RenderMixin):
                     ret[field.field_name] = field.to_representation(attribute)
                 else:
                     ret[field.field_name] = field.to_representation(attribute, instance)
